! jan.kazil@noaa.gov 2024-08-23 20:32:56 -06:00

PROGRAM TEST_RUN
  
  !
  ! Creates and saves in a file a 3D water vapor distribution with a mesoscale anomaly.
  !
  
  use module_water_vapor_initialization
  
  implicit none
  
  ! Grid size
  
  integer :: x_n,y_n,z_n
  
  ! Horizontal grid spacing
  
  double precision :: dx,dy
  
  ! Coordinates
  
  double precision, allocatable :: x(:),y(:),z(:)
  
  ! Water vapor profile and 3D distribution
  
  double precision, allocatable :: qv_z(:),qv_xyz(:,:,:)
  
  ! Parameters of the water vapor mesoscale anomaly
  
  double precision :: center_x ! Center of the anomaly in x-direction (m)
  double precision :: center_y ! Center of the anomaly in y-direction (m)
  double precision :: base     ! Base of the anomaly in z-direction (m)
  double precision :: top      ! Top of the anomaly in z-direction (m)
  double precision :: radius   ! Radius of the anomaly (m)
  double precision :: dq       ! Full amplitude (trough to peak) of the anomaly (kg kg-1)
  
  !
  ! Do your worst
  !
  
  ! Set horizontal grid
  
  x_n = 960
  y_n = 960
  
  dx = 150.0D0
  dy = 150.0D0
  
  ! Initialize water vapor with a given profile
  
  call initialize_water_vapor_z(z_n,z,qv_z)
  
  call initialize_water_vapor_xyz(x_n,y_n,z_n,dx,dy,x,y,z,qv_z,qv_xyz)
  
  ! Save the water vapor without the anomaly in a binary file
  
  call save_data(10,'qv_without_anomaly.bin',x_n,y_n,z_n,x,y,z,qv_xyz)
  
  ! Apply the water vapor mesoscale anomaly
  
  base     = 0.0D0     ! m
  top      = 1100.0D0  ! m
  center_x = 72000.0D0 ! m
  center_y = 72000.0D0 ! m
  radius   = 72000.0D0 ! m
  dq       = 0.001D0   ! kg kg-1
  
  call initialize_water_vapor_mesoscale_anomaly(x_n,y_n,z_n,dx,dy,z,qv_xyz,center_x,center_y,base,top,radius,dq)
  
  ! Save the water vapor with the anomaly in a binary file
  
  call save_data(10,'qv_with_anomaly.bin',x_n,y_n,z_n,x,y,z,qv_xyz)
  
END PROGRAM TEST_RUN
